@@ -33,6 +33,20 @@ class DerivedDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {FundIndicator.__tablename__}')
 
+    def delete_fund_indicator_with_dt(self, date_list):
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                session.query(
+                    FundIndicator
+                ).filter(
+                    FundIndicator.datetime.in_(date_list),
+                ).delete(synchronize_session=False)
+                session.commit()
+                return True
+            except Exception as e:
+                print(f'failed to delete data <err_msg> {e} from {FundIndicator.__tablename__}')
+                return False
+
     def get_fund_indicator_by_date(self, fund_list, date):
         with DerivedDatabaseConnector().managed_session() as quant_session:
             try:
@@ -720,11 +734,13 @@ class DerivedDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'failed to get_fof_nav_public <err_msg> {e} from {FOFNavPublic.__tablename__}')
 
-    def get_fof_nav_calc(self, fof_id_list: Tuple[str] = ()):
+    def get_fof_nav_calc(self, manager_id, fof_id_list: Tuple[str] = ()):
         with DerivedDatabaseConnector().managed_session() as session:
             try:
                 query = session.query(
                     FOFNavCalc,
+                ).filter(
+                    FOFNavCalc.manager_id == manager_id,
                 )
                 if fof_id_list:
                     query = query.filter(
@@ -922,13 +938,15 @@ class DerivedDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'failed to get_hedge_fund_custodian_data <err_msg> {e} from {HedgeFundCustodianData.__tablename__}')
 
-    def delete_hedge_fund_custodian_data(self, id_to_delete: int) -> bool:
+    def delete_hedge_fund_custodian_data(self, manager_id: str, fof_id: str, datetime) -> bool:
         with DerivedDatabaseConnector().managed_session() as session:
             try:
                 session.query(
                     HedgeFundCustodianData
                 ).filter(
-                    HedgeFundCustodianData.id == id_to_delete,
+                    HedgeFundCustodianData.manager_id == manager_id,
+                    HedgeFundCustodianData.fof_id == fof_id,
+                    HedgeFundCustodianData.datetime == datetime,
                 ).delete(synchronize_session=False)
                 session.commit()
                 return True
@@ -968,6 +986,9 @@ class DerivedDataApi(metaclass=Singleton):
             basic_api = BasicDataApi()
             begin_date, end_date = raw_api.get_date_range(time_para, begin_date, end_date)
             stock_df = raw_api.get_em_stock_info()
+            today = datetime.date.today()
+            _b_d = today - datetime.timedelta(days=90)
+            stock_df = stock_df[stock_df.list_date < _b_d]
             stock_df = stock_df[['stock_id','name','bl_sws_ind_code']].dropna()
             stock_df.loc[:,'industry_1'] = stock_df.bl_sws_ind_code.map(lambda x: x.split('-')[0])
             stock_df.loc[:,'industry_2'] = stock_df.bl_sws_ind_code.map(lambda x: x.split('-')[1])
@@ -1022,21 +1043,39 @@ class DerivedDataApi(metaclass=Singleton):
             print(f'failed to get data <err_msg> {e} from derived.get_industry_stock_ret_and_size')
             return False
         
-    def get_all_industry_val(self, begin_date, end_date, time_para):
+    def get_all_industry_val(self, begin_date, end_date, time_para, value_type='估值',industry_type='一级行业'):
         try:
-            raw_api = RawDataApi()
-            begin_date, end_date = raw_api.get_date_range(time_para, begin_date, end_date)
+            industry_type_dic = {
+                '一级行业':1,
+                '二级行业':2
+            }
             dic = {
                 'pb_mrq':'PB',
                 'roe':'ROE'
             }
-            index_info = BasicDataApi().get_asset_info_by_type(['行业指数'])
-            index_ids = index_info.real_id.tolist()
-            asset_name = index_info.set_index('real_id').to_dict()['asset_name']
-            df = self.get_index_valuation_last_date(dt=end_date, index_ids=index_ids)
-            df = df.set_index('index_id')[dic.keys()].rename(columns=dic).round(2)
-            df.loc[:,'desc_name'] = df.index.map(asset_name)
-            df = df.reset_index(drop=True)
+            raw_api = RawDataApi()
+            begin_date, end_date = raw_api.get_date_range(time_para, begin_date, end_date)
+            industry_info_raw = RawDataApi().get_em_industry_info(ind_class_type=industry_type_dic[industry_type])
+            em_id_raw = industry_info_raw.em_id.tolist()
+            index_info = BasicDataApi().get_index_info_by_em_id(em_id_list=em_id_raw)
+            index_ids = index_info.index_id.tolist()
+            asset_name = index_info.set_index('index_id').to_dict()['desc_name']
+            if value_type == '估值':
+                df = self.get_index_valuation_last_date(dt=end_date, index_ids=index_ids)
+                df = df.set_index('index_id')[dic.keys()].rename(columns=dic).round(2)
+                df.loc[:,'desc_name'] = df.index.map(asset_name)
+                df = df.reset_index(drop=True)
+            elif value_type == '估值分位':
+                df = DerivedDataApi().get_index_valuation_develop(end_date=end_date,start_date=begin_date,index_ids=index_ids)
+                index_pb = df.pivot_table(index='datetime',columns='index_id',values='pb_mrq')
+                index_roe = df.pivot_table(index='datetime',columns='index_id',values='roe')
+                pb_rank = index_pb.rank(pct=True, axis=0).iloc[-1]
+                pb_rank.name = 'PB'
+                roe_rank = index_roe.rank(pct=True, axis=0).iloc[-1]
+                roe_rank.name = 'ROE'
+                df = pd.concat([pb_rank, roe_rank],axis=1)
+                df.loc[:,'desc_name'] = df.index.map(asset_name)
+            
             _x = df.ROE.values
             x = sm.add_constant(_x)
             y = df.PB.values
@@ -1046,6 +1085,8 @@ class DerivedDataApi(metaclass=Singleton):
             x_array = np.arange(min(_x),max(_x), (max(_x)-min(_x))/100)
             y_array = k*x_array + c
             df_line = pd.DataFrame({'ROE':x_array,'PB':y_array,}).round(2)
+            df['PB'] = df['PB'].round(2)
+            df['ROE'] = df['ROE'].round(2)
             data = {
                 '散点':df,
                 '虚线':df_line,
