@@ -1,10 +1,14 @@
 import traceback
 import json
+import datetime
+import pandas as pd
+
 from ...manager.manager_fund import *
 from ...view.derived_models import *
 from .derived_data_helper import DerivedDataHelper
 
-class TopManagerFundProcessor(object):
+
+class TopManagerFundProcessor:
 
     def __init__(self, data_helper):
         self._data_helper = data_helper
@@ -21,7 +25,7 @@ class TopManagerFundProcessor(object):
             trading_days = pd.read_sql(query.statement, query.session.bind)
             self.trading_dates = trading_days[trading_days['datetime'] >= self.start_date].datetime
 
-        with DerivedDatabaseConnector().managed_session() as session:        
+        with DerivedDatabaseConnector().managed_session() as session:
             query = session.query(
                 FundManagerScore
             ).filter(
@@ -30,8 +34,7 @@ class TopManagerFundProcessor(object):
                 FundManagerScore.datetime <= self.end_date,
             )
             self.mng_score_df = pd.read_sql(query.statement, query.session.bind)
-            self.mng_score_df = self.mng_score_df.set_index(['datetime','manager_id']).drop(columns='fund_type')
-
+            self.mng_score_df = self.mng_score_df.set_index(['datetime', 'manager_id']).drop(columns='fund_type')
             query = session.query(
                 FundManagerFundRank
             ).filter(
@@ -39,14 +42,15 @@ class TopManagerFundProcessor(object):
                 FundManagerFundRank.datetime <= self.end_date,
             )
             self.mng_fund_list = pd.read_sql(query.statement, query.session.bind)
-            self.mng_fund_list = self.mng_fund_list.set_index(['datetime','mng_id'])
-        
+            self.mng_fund_list = self.mng_fund_list.set_index(['datetime', 'mng_id'])
+
     def calculate_update(self):
         res = []
         for dt in self.trading_dates:
             try:
-                top_mng_list = self.mng_score_df.loc[dt].sort_values('score',ascending=False).index.tolist()
-                mng_fund_dt = self.mng_fund_list.loc[dt]
+                pd_dt = pd.to_datetime(dt, infer_datetime_format=True)
+                top_mng_list = self.mng_score_df.loc[pd_dt].sort_values('score', ascending=False).index.tolist()
+                mng_fund_dt = self.mng_fund_list.loc[pd_dt]
                 mng_fund_dt_list = mng_fund_dt.index.tolist()
                 top_mng_list = [_ for _ in top_mng_list if (_ in mng_fund_dt_list)]
                 top_funds = [json.loads(_)[0] for _ in mng_fund_dt.loc[top_mng_list].fund_list.values]
@@ -57,7 +61,7 @@ class TopManagerFundProcessor(object):
                 for idx, i in enumerate(top_funds):
                     dic.update({f'top_{idx+1}':i})
                 res.append(dic)
-            except:
+            except Exception:
                 continue
         self.result = pd.DataFrame(res)
 
@@ -77,4 +81,9 @@ class TopManagerFundProcessor(object):
             failed_tasks.append('top_manager_funds')
 
         return failed_tasks
-        
\ No newline at end of file
+
+
+if __name__ == "__main__":
+    the_date = '20210111'
+    tmfp = TopManagerFundProcessor(DerivedDataHelper())
+    tmfp.process(the_date, the_date)
