@@ -69,7 +69,6 @@ class FOFNAVReader:
         df = df.loc[:, ['估值日期', '单位净值', '累计单位净值']]
         df = df.rename(columns=FOFNAVReader.COLUMNS_DICT)
         df['fof_id'] = self._fof_id
-        print(df)
         return df
 
     @staticmethod
@@ -106,7 +105,7 @@ class FOFNAVReader:
 
     def _notify_error_event(self, err_msg: str):
         print(f'[read_navs_and_dump_to_db] {err_msg}')
-        self._wechat_bot.send_hedge_fund_nav_update_failed(err_msg)
+        # self._wechat_bot.send_hedge_fund_nav_update_failed(err_msg)
 
     def read_navs_and_dump_to_db(self):
         fof_info = BasicDataApi().get_fof_info(self._manager_id, [self._fof_id])
@@ -123,7 +122,7 @@ class FOFNAVReader:
             uid_last = None
 
         try:
-            mar = MailAttachmentRetriever(self._read_dir)
+            mar = MailAttachmentRetriever(self._read_dir, ['xls', 'xlsx', 'pdf'])
             data = mar.get_excels(self._sp_uri, self._user_name, self._password, uid_last)
         except Exception as e:
             self._notify_error_event(f'FATAL ERROR!! get new data of hedge fund nav failed (e){e} (manager_id){self._manager_id} (fof_id){self._fof_id}')
@@ -137,29 +136,36 @@ class FOFNAVReader:
             '华泰证券': FOFNAVReader._read_for_HuaTaiSec,
         }
 
+        can_not_update = False
         uid_last_succeed: Optional[bytes] = None
         df_list: List[pd.DataFrame] = []
         for name, comp_date in data.items():
             uid, file_path = comp_date
-            if '.xls' not in name and '.xlsx' not in name and 'pdf' not in name:
-                self._notify_error_event(f'not a valid file, do not process it (name){name} (file_path){file_path} (manager_id){self._manager_id} (fof_id){self._fof_id}')
-                continue
 
             try:
                 for c_name, func in parsers.items():
-                    try:
-                        df = func(file_path)
-                    except Exception:
-                        pass
-                    else:
-                        if c_name in custodian_name:
+                    if c_name in custodian_name:
+                        try:
+                            df = func(file_path)
+                            print(df)
+                        except Exception:
+                            pass
+                            # can_not_update = True
+                        else:
                             break
                 else:
                     raise NotImplementedError(f'unknown hedge fund nav file from attachment (manager_id){self._manager_id} (fof_id){self._fof_id}')
             except Exception as e:
-                # self._notify_error_event(f'{e} (parse) (name){name} (file_path){file_path} (manager_id){self._manager_id} (fof_id){self._fof_id}')
+                if not can_not_update:
+                    # 走到这里都认为是已经处理完了这条数据
+                    uid_last_succeed = uid
+                self._notify_error_event(f'{e} (parse) (name){name} (file_path){file_path} (manager_id){self._manager_id} (fof_id){self._fof_id}')
                 continue
 
+            if not can_not_update:
+                # 走到这里都认为是已经处理完了这条数据
+                uid_last_succeed = uid
+
             try:
                 df = df[df.fof_id == self._fof_id]
                 if df.empty:
@@ -171,8 +177,6 @@ class FOFNAVReader:
                     df_list.append(df)
                 else:
                     print(f'[read_navs_and_dump_to_db] duplicated data, do not process it (name){name} (manager_id){self._manager_id} (fof_id){self._fof_id}')
-                # 走到这里都认为是已经处理完了这条数据
-                uid_last_succeed = uid
                 time.sleep(1)
             except Exception as e:
                 traceback.print_exc()
@@ -183,7 +187,7 @@ class FOFNAVReader:
             try:
                 whole_df = pd.concat(df_list).set_index('fof_id')
                 print(whole_df)
-                self._wechat_bot.send_hedge_fund_nav_update(whole_df)
+                # self._wechat_bot.send_hedge_fund_nav_update(whole_df)
             except Exception as e:
                 self._notify_error_event(f'{e} (concat) (manager_id){self._manager_id} (fof_id){self._fof_id}')
                 return
@@ -212,7 +216,7 @@ class FOFNAVReader:
 
         # TODO:
         assert df.datetime.nunique() == 1, 'should have single datetime'
-        now_df = DerivedDataApi().get_fof_nav([self._fof_id])
+        now_df = DerivedDataApi().get_fof_nav(self._manager_id, [self._fof_id])
         if now_df is not None and not now_df.empty:
             # 同产品同日期的净值如果已经存在了且没有变化，就不写DB了
             now_df = now_df.drop(columns=['update_time', 'create_time', 'is_deleted', 'volume', 'mv', 'ret']).sort_values(by=['fof_id', 'datetime']).drop_duplicates(subset=['fof_id', 'datetime'], keep='last')
