@@ -220,7 +220,7 @@ class HedgeFundNAVReader:
             uid_last = None
 
         try:
-            mar = MailAttachmentRetriever(self._read_dir)
+            mar = MailAttachmentRetriever(self._read_dir, ['xls', 'xlsx', 'pdf'])
             data = mar.get_excels(IMAP_SPType.IMAP_QQ, self._user_name, self._password, uid_last)
         except Exception as e:
             self._notify_error_event(f'FATAL ERROR!! get new data of hedge fund nav failed (e){e}')
@@ -230,9 +230,6 @@ class HedgeFundNAVReader:
         df_list: List[pd.DataFrame] = []
         for name, comp_date in data.items():
             uid, file_path = comp_date
-            if not name.endswith('.xls') and not name.endswith('.xlsx') and not name.endswith('.pdf'):
-                self._notify_error_event(f'not a valid file, do not process it (name){name} (file_path){file_path}')
-                continue
 
             try:
                 if 'SLW695' in name:
