@@ -794,6 +794,16 @@ class FundTag(Base):
     tag_name = Column(CHAR(64)) # 标签名
 
 
+class HedgeFundAlias(FOFBase):
+    '''私募基金别名'''
+
+    __tablename__ = 'hedge_fund_alias'
+
+    fund_id_alias = Column(CHAR(16), primary_key=True)  # 私募基金ID别名
+    manager_id = Column(CHAR(32), primary_key=True)  # 管理端ID
+    fund_id = Column(CHAR(16))  # 基金ID
+
+
 class HedgeFundNAV(FOFBase):
     '''私募基金净值'''
 
@@ -1187,3 +1197,14 @@ class FOFOtherRecord(FOFBase):
     amount = Column(DOUBLE(asdecimal=False))                        # 金额
     remark = Column(VARCHAR(255))                                   # 备注
 
+
+class FOFAssertCorrect(FOFBase):
+    """净资产修正"""
+    __tablename__ = 'fof_assert_correct'
+
+    id = Column(Integer, primary_key=True, autoincrement=True)
+    fof_id = Column(CHAR(16), primary_key=True)                     # 产品ID
+    manager_id = Column(CHAR(32), primary_key=True)                 # 管理端ID
+    date = Column(DATE)                                             # 日期
+    amount = Column(DOUBLE(asdecimal=False))                        # 金额
+    remark = Column(VARCHAR(255))                                   # 备注
