@@ -744,6 +744,10 @@ class FOFNavCalc(FOFBase):
     adjusted_nav = Column(DOUBLE(asdecimal=False))          # 复权净值
     volume = Column(DOUBLE(asdecimal=False))                # 份额
     mv = Column(DOUBLE(asdecimal=False))                    # 市值
+    interest = Column(DOUBLE(asdecimal=False))              # 利息
+    management_fee = Column(DOUBLE(asdecimal=False))        # 管理费
+    custodian_fee = Column(DOUBLE(asdecimal=False))         # 托管费
+    administrative_fee = Column(DOUBLE(asdecimal=False))    # 行政管理费
     ret = Column(DOUBLE(asdecimal=False))                   # 累计收益率
     manager_id = Column(CHAR(32))                           # 管理端ID
 
