@@ -1146,6 +1146,171 @@ class Calculator:
         df = df[df.index.tolist()]
         return df
 
+    @staticmethod
+    def get_rolling_corr(fund_navs, windows, frequency, step=1):
+        try:
+            if frequency == '日度':
+                rule = '1D'
+                windows = int(windows / 1)
+            if frequency == '周度':
+                rule = '1W'
+                windows = int(windows / 5)
+            if frequency == '月度':
+                rule = '1M'
+                windows = int(windows / 20)
+
+            fund_navs_period = CalculatorBase.data_resample_weekly_nav(df=fund_navs, rule=rule)
+            fund_ret = fund_navs_period.pct_change(1).iloc[1:]  
+            # 弱鸡排列
+            col_pair = []
+            cols = fund_ret.columns.tolist()
+            for idx_i, col_i in enumerate(cols):
+                cols_list = cols[idx_i+1:]
+                for idx_j, col_j in enumerate(cols_list):
+                    col_pair.append([col_i,col_j])
+
+            corr_result_df = []
+            for col_pair_i in col_pair:
+                df = fund_ret[col_pair_i]
+                idx_list = df.reset_index().index.tolist()
+                corr_result = []
+                b = idx_list[0]
+                _result = []
+                
+                # 计算窗口划分 不包含min_windows概念
+                while(1):
+                    e = b + windows
+                    if e > idx_list[-1]:
+                        break
+                    else:
+                        _result.append([b,e])
+                        b += step
+
+                # 计算部分
+                for idxs in _result:
+                    _df = df.iloc[idxs[0]:idxs[1]]
+                    corr_result.append({'datetime':_df.index[-1], f'{col_pair_i[0]}_{col_pair_i[1]}':_df.corr().iloc[1,0]})
+                df = pandas.DataFrame(corr_result).set_index('datetime')
+                corr_result_df.append(df)
+            return pandas.concat(corr_result_df,axis=1).dropna()
+
+        except Exception as e:
+            print(f'Failed to get data <err_msg> {e} from portfolio.get_rolling_corr')
+
+
+    @staticmethod
+    def get_product_rolling_corr(fund_navs, windows=20, period='周度', index_id='hs300'):
+        try:
+            basic = BasicDataApi()
+            index_name = basic.get_index_info([index_id]).desc_name.tolist()[0]
+            if index_name in fund_navs:
+                pass
+            else:
+                index_price = basic.get_index_price([index_id]).pivot_table(index='datetime',columns='index_id',values='close')
+                index_price.columns = [index_name]
+                index_price = index_price.reindex(fund_navs.index.union(index_price.index)).ffill()
+                fund_navs = fund_navs.join(index_price).sort_index()
+            
+            result = Calculator.get_rolling_corr(fund_navs, windows, period)
+            if result.shape[0] > 50:
+                result = result.iloc[-50:]
+            corr_details = {}
+            cols = result.columns.tolist()
+            for r in result.iterrows():
+                _result = []
+                for col in cols:
+                    x = col.split('_')[0]
+                    y = col.split('_')[1]
+                    
+                    dic_1 = {
+                        'x' : x,
+                        'y' : y,
+                        'v' : r[1][col],
+                    }
+                    
+                    dic_2 = {
+                        'x' : y,
+                        'y' : x,
+                        'v' : r[1][col]
+                    }
+                    _result.append(dic_1)
+                    _result.append(dic_2)
+                unique_list = set([item for sublist in cols for item in sublist.split('_')])
+                _result += [{'x':i,'y':i,'v':i} for i in  unique_list]
+                df_dt = pandas.DataFrame(_result).pivot(index='x',columns='y',values='v')
+                df_dt.columns.name = None
+                df_dt.index.name = 'index_id'
+                corr_details[str(r[0])] = df_dt
+            return {
+                'data':result,
+                'details':corr_details
+            }
+
+        except Exception as e:
+            print(f'Failed to get data <err_msg> {e} from calculator.get_product_rolling_corr')
+
+    @staticmethod
+    def get_product_rolling_beta(fund_navs, windows=20, period='周度', index_id='hs300'):
+        try:
+            if period == '日度':
+                rule = '1D'
+                windows = int(windows / 1)
+            if period == '周度':
+                rule = '1W'
+                windows = int(windows / 5)
+            if period == '月度':
+                rule = '1M'
+                windows = int(windows / 20)
+
+            basic = BasicDataApi()
+            index_name = basic.get_index_info([index_id]).desc_name.tolist()[0]
+            if index_name in fund_navs:
+                pass
+            else:
+                index_price = basic.get_index_price([index_id]).pivot_table(index='datetime',columns='index_id',values='close')
+                index_price.columns = [index_name]
+                index_price = index_price.reindex(fund_navs.index.union(index_price.index)).ffill()
+                fund_navs = fund_navs.join(index_price).sort_index()
+
+            fund_navs_period = CalculatorBase.data_resample_weekly_nav(df=fund_navs, rule=rule)
+            fund_ret = fund_navs_period.pct_change(1).iloc[1:].dropna()  
+            result = []
+            for fund_name in fund_ret:
+                if fund_name == index_name:
+                    continue
+                else:
+                    df = fund_ret[[fund_name, index_name]].rename(columns={fund_name:'fund',index_name:'benchmark'}).reset_index()
+                    res = []
+                    pandas.Series(df.index).rolling(
+                        window=windows).apply(
+                        partial(Calculator.rolling_alpha_beta, res=res, df=df), raw=True)
+                    df = pandas.DataFrame(res,index=df.datetime[-len(res):])
+                    df = df[['beta']].rename(columns={'beta':f'{fund_name}'})
+                    result.append(df)
+            result = pandas.concat(result, axis=1)
+            return result
+
+        except Exception as e:
+            print(f'Failed to get data <err_msg> {e} from calculator.get_product_rolling_beta')
+
+    @staticmethod
+    def rolling_alpha_beta(x, res, df):
+        df_i = df.loc[x[0]:x[-1],]
+        return Calculator._rolling_alpha_beta(res, df_i)
+
+    @staticmethod
+    def _rolling_alpha_beta(res, df_i):
+        if sum(df_i.fund) == 0:
+            res.append({'alpha':np.Inf,'beta':np.Inf})
+            return 1
+        else:
+            ploy_res = np.polyfit(y=df_i.fund, x=df_i.benchmark,deg=1)
+            p = np.poly1d(ploy_res)
+            beta = ploy_res[0]
+            alpha = ploy_res[1] * Calculator.TRADING_DAYS_PER_YEAR
+            res.append({'alpha':alpha,'beta':beta})
+            return 1
+
 if __name__ == "__main__":
     # get pct with select rank
     Calculator.get_index_pct_data_df()
